==> haskell-onetuple-0.4.2-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-onetuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 OneTuple
version:              0.4.2
visibility:           public
id:                   OneTuple-0.4.2-3CeSkaxtMkG9rfkZdvylk0
key:                  OneTuple-0.4.2-3CeSkaxtMkG9rfkZdvylk0
license:              BSD-3-Clause
copyright:            (c) John Dorsey 2008
maintainer:
    Oleg Grenrus <oleg.grenrus@iki.fi>, John Dorsey <haskell@colquitt.org>

author:               John Dorsey <haskell@colquitt.org>
stability:            experimental
synopsis:             Singleton Tuple
description:
    This package is a compatibility package for a singleton data type

    > data Solo a = MkSolo a

    Note: it'\''s not a @newtype@

    @Solo@ is available in @base-4.16@ (GHC-9.2).

category:             Data
abi:                  aadc2d40bc5bddcadc2bca6a5ce367aa
exposed:              True
exposed-modules:
    Data.Tuple.OneTuple Data.Tuple.Solo Data.Tuple.Solo.TH

import-dirs:          /usr/lib/ghc-9.4.8/site-local/OneTuple-0.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/OneTuple-0.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/OneTuple-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-onetuple
hs-libraries:         HSOneTuple-0.4.2-3CeSkaxtMkG9rfkZdvylk0
depends:
    base-4.17.2.1 ghc-prim-0.9.1 template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-onetuple/html/OneTuple.haddock
haddock-html:         /usr/share/doc/haskell-onetuple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-onetuple-0.4.2-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-onetuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 OneTuple
version:              0.4.2
visibility:           public
id:                   OneTuple-0.4.2-JCo97y3vRnM9FXkOt3LjRA
key:                  OneTuple-0.4.2-JCo97y3vRnM9FXkOt3LjRA
license:              BSD-3-Clause
copyright:            (c) John Dorsey 2008
maintainer:
    Oleg Grenrus <oleg.grenrus@iki.fi>, John Dorsey <haskell@colquitt.org>

author:               John Dorsey <haskell@colquitt.org>
stability:            experimental
synopsis:             Singleton Tuple
description:
    This package is a compatibility package for a singleton data type

    > data Solo a = MkSolo a

    Note: it'\''s not a @newtype@

    @Solo@ is available in @base-4.16@ (GHC-9.2).

category:             Data
abi:                  5e4728775c8a124bf6a55267468502d3
exposed:              True
exposed-modules:
    Data.Tuple.OneTuple Data.Tuple.Solo Data.Tuple.Solo.TH

import-dirs:          /usr/lib/ghc-9.4.8/site-local/OneTuple-0.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/OneTuple-0.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/OneTuple-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-onetuple
hs-libraries:         HSOneTuple-0.4.2-JCo97y3vRnM9FXkOt3LjRA
depends:
    base-4.17.2.1 ghc-prim-0.9.1 template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-onetuple/html/OneTuple.haddock
haddock-html:         /usr/share/doc/haskell-onetuple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
